#******************************************************************************/
#*      Load libraries that fill namespace HepMC                              */
#*                                                                            */
#*                                           Sebastian Boeser, 13.09.07       */
#******************************************************************************/

#-- ConfigParser
import ConfigParser

#-- Athena logging
from AthenaCommon.Logging import logging
mlog = logging.getLogger('HepMCBrowser')

#-- Athena application interface
from AthenaCommon.AppMgr import theApp

#-- OS tools
import os

#-- ROOT classes
import ROOT

#-- ROOT globals
from ROOT import gSystem

#the configuration file path
configfile="HepMCBrowser.cfg"

#new config parser
config = ConfigParser.ConfigParser()

#read the config file
config.read(configfile)

#list of library options that we expect
#the second parameter in the list tells wether the library is mandatory
libopt = [["libHepMC",True],
          ["libHepMCVisual",True],
          ["libHepMCReflex",False]]

#loop over library option
for opt in libopt:
  
  #check if option is found
  if not config.has_option("libs",opt[0]):
    
    #send a warning message
    mlog.warning("Option "+opt[0]+" not found in section libs in "+configfile)

    #check if option is mandatory
    if opt[1]:
      
      #send an error message
      mlog.fatal("Could not load "+opt[0]+" -- aborting!!!")

      #and quit
      theApp.exit()
    else :
      
      #jump to next option
      continue
  
  #try to load the library
  libpath=config.get("libs",opt[0])
  rc = gSystem.Load(libpath)

  #check return code
  if rc < 0 :

    #send an error message
    mlog.error("Could not load "+opt[0]+" form "+libpath+" !" )

    #check if option is mandatory
    if opt[1]:
      
      #send an error message
      mlog.fatal("Could not load "+opt[0]+" -- aborting!!!")

      #and quit
      theApp.exit()
    else :
      
      #jump to next option
      continue
   
  else :
    
   #everthing okay
   mlog.info("Successfully loaded "+opt[0])

